@@ -4,7 +4,6 @@
 import functools
 import logging
 
-import requests
 import time
 
 import pika
@@ -35,7 +34,7 @@ class SDKConsumer(object):
     # QUEUE = 'resizer'
     ROUTING_KEY = 'example.text'
 
-    def __init__(self, amqp_url, queue_name, core_url, action):
+    def __init__(self, amqp_url, queue_name, action):
         """Create a new instance of the consumer class, passing in the AMQP
         URL used to connect to RabbitMQ.
 
@@ -55,7 +54,6 @@ class SDKConsumer(object):
         # for higher consumer throughput
         self._prefetch_count = 1
         self._queue_name = queue_name
-        self._core_url = core_url
 
         self._action = action
 
@@ -292,7 +290,10 @@ class SDKConsumer(object):
 
         # Enroll to core-server
         data={'name': self._action.name, 'tag': self._consumer_tag}
-        requests.post(f"{self._core_url}/consumer", json=data)
+
+        # Should send to registration queue
+
+        # requests.post(f"{self._core_url}/consumer", json=data)
 
     def add_on_cancel_callback(self):
         """Add a callback that will be invoked if RabbitMQ cancels the consumer
@@ -330,16 +331,19 @@ class SDKConsumer(object):
 
         """
         LOGGER.info('Received message # %s from %s: %s',
-                    basic_deliver.delivery_tag, properties.app_id, body)
+                    basic_deliver.delivery_tag, properties.app_id, 'image=====')
 
         LOGGER.info(f' Sous-classe actions => {Action.__subclasses__()}')
 
         action = Action.__subclasses__()[0]()
+        print(f"extract {action} {properties.headers}======================================================")
         params, operations, pipeline_id, step_id, name, extension = extract_informations(properties.headers)
-        resend(body, params, operations, pipeline_id, step_id, self._consumer_tag, self._core_url, "started", None,
-               name, extension)
-
+        print(f"extract {params} {operations} {pipeline_id} {step_id} {name} {extension}======================================================")
+        resend(body, params, pipeline_id, step_id, self._consumer_tag, "started", None,
+               name, extension, self._url)
+        print(f"Resended======================================================")
         try:
+            print(f"launch action {action} {properties.headers}======================================================")
             result = action.execute(properties, body)
             if result:
                 body = result
@@ -352,8 +356,8 @@ class SDKConsumer(object):
 
         params, operations, pipeline_id, step_id, name, extension = extract_informations(properties.headers)
 
-        resend(body, params, operations, pipeline_id, step_id, self._consumer_tag, self._core_url, status, reason,
-               name, extension)
+        resend(body, params, pipeline_id, step_id, self._consumer_tag, status, reason,
+               name, extension, self._url)
 
         self.acknowledge_message(basic_deliver.delivery_tag)
 
@@ -438,13 +442,12 @@ class ReconnectingExampleConsumer(object):
 
     """
 
-    def __init__(self, amqp_url, queue_name, core_url, action):
+    def __init__(self, amqp_url, queue_name, action):
         self._reconnect_delay = 0
         self._amqp_url = amqp_url
         self._queue_name = queue_name
-        self._core_url = core_url
         self._action = action
-        self._consumer = SDKConsumer(self._amqp_url, self._queue_name, self._core_url, action)
+        self._consumer = SDKConsumer(self._amqp_url, self._queue_name, action)
 
     def run(self):
         while True:
@@ -461,7 +464,7 @@ class ReconnectingExampleConsumer(object):
             reconnect_delay = self._get_reconnect_delay()
             LOGGER.info('Reconnecting after %d seconds', reconnect_delay)
             time.sleep(reconnect_delay)
-            self._consumer = SDKConsumer(self._amqp_url, self._queue_name, self._core_url, self._action)
+            self._consumer = SDKConsumer(self._amqp_url, self._queue_name, self._action)
 
     def _get_reconnect_delay(self):
         if self._consumer.was_consuming:
