@@ -8,8 +8,8 @@ class ExtractInformationsTest(TestCase):
     def test_should_have_tags(self):
         headers = {'params': {'tags': ['cat', 'dog']},
                    'operations': ['to_save'],
-                   'pipeline': 'idp',
-                   'step': 'ids',
+                   'pipeline_id': 'idp',
+                   'step_id': 'ids',
                    'name': 'test',
                    'extension': 'jpeg'}
 
